@@ -6,7 +6,7 @@
  
 typedef struct 
 {
-    uint32_t iDummy[10];
+    int32_t iDummy[10];
     double fDummy[10];
     char cDummy[10][20];
 }__attribute__ ((__packed__)) ResSummaryMiscStruct;
